@@ -25,6 +25,11 @@
 #include <QToolButton>
 #include <QFrame>
 #include <QDebug>
+#include <QLabel>
+#include <QMenu>
+#include <QEvent>
+#include <QHideEvent>
+#include <QScrollArea>
 
 typedef struct UkuiThemeIcon
 {
@@ -41,10 +46,16 @@ enum SwitchButtonState{
     SWITCH_BUTTON_PRESS
 };
 static QColor symbolic_color = Qt::gray;
-//class UkuiDeviceButton:public QPushButton
-//{
 
-//}
+class UkuiMediaSliderTipLabel:public QLabel
+{
+  public:
+    UkuiMediaSliderTipLabel();
+    ~UkuiMediaSliderTipLabel();
+protected:
+    void paintEvent(QPaintEvent*);
+};
+
 class UkuiButtonDrawSvg:public QPushButton
 {
     Q_OBJECT
@@ -75,7 +86,7 @@ protected:
     void paintEvent(QPaintEvent*);
 };
 
-class UkuiMediaButton:public QToolButton
+class UkuiMediaButton:public QPushButton
 {
     Q_OBJECT
 public:
@@ -102,21 +113,74 @@ class UkmediaVolumeSlider : public QSlider
 {
     Q_OBJECT
 public:
-    UkmediaVolumeSlider(QWidget *parent = nullptr);
+//    UkmediaVolumeSlider(QWidget *parent = nullptr);
+    UkmediaVolumeSlider(QWidget *parent = nullptr,bool needTip = false);
     void initStyleOption(QStyleOptionSlider *option);
     ~UkmediaVolumeSlider();
-
 Q_SIGNALS:
-    void silderPressedSignal(int);
+    void silderPressSignal();
+    void silderReleaseSignal();
+private:
+    UkuiMediaSliderTipLabel *m_pTiplabel;
+    bool state = false;
+    bool mousePress = false;
+
 
 protected:
     void mousePressEvent(QMouseEvent *ev);
+    void mouseReleaseEvent(QMouseEvent *e);
     void mouseMoveEvent(QMouseEvent *e)
     {
-        setCursor(QCursor(Qt::OpenHandCursor));
+        int value = 0;
+        int currentX = e->pos().x();
+        double per = currentX * 1.0 / this->width();
+        if ((this->maximum() - this->minimum()) >= 50) { //减小鼠标点击像素的影响
+            value = qRound(per*(this->maximum() - this->minimum())) + this->minimum();
+            if (value <= (this->maximum() / 2 - this->maximum() / 10 + this->minimum() / 10)) {
+                value = qRound(per*(this->maximum() - this->minimum() - 1)) + this->minimum();
+            } else if (value > (this->maximum() / 2 + this->maximum() / 10 + this->minimum() / 10)) {
+                value = qRound(per*(this->maximum() - this->minimum() + 1)) + this->minimum();
+            } else {
+                value = qRound(per*(this->maximum() - this->minimum())) + this->minimum();
+            }
+        } else {
+            value = qRound(per*(this->maximum() - this->minimum())) + this->minimum();
+        }
+        this->setValue(value);
+        QSlider::mousePressEvent(e);
+//        setCursor(QCursor(Qt::OpenHandCursor));
 //        m_displayLabel->move((this->width()-m_displayLabel->width())*this->value()/(this->maximum()-this->minimum()),3);
-        QSlider::mouseMoveEvent(e);
+//        QSlider::mouseMoveEvent(e);
     }
+    void leaveEvent(QEvent *e);
+
+    void enterEvent(QEvent *e);
+    void paintEvent(QPaintEvent *e);
+};
+
+class UkuiScrollArea : public QScrollArea
+{
+    Q_OBJECT
+public:
+    UkuiScrollArea(QWidget *parent = nullptr);
+    ~UkuiScrollArea();
+
+protected:
+    void paintEvent(QPaintEvent *e);
+
+};
+
+class UkuiQMenu:public QMenu
+{
+    Q_OBJECT
+public:
+    UkuiQMenu();
+    ~UkuiQMenu();
+protected:
+    void hideEvent(QHideEvent *e);
+    virtual bool event(QEvent *e) override;
+
+
 };
 
 #endif // UKMEDIAVOLUMESLIDER_H
